

Project: ChemMod.py


Description:
<svg fill="none" viewBox="0 0 600 300" width="600" height="300">
  <foreignObject width="100%" height="100%">
<div id="d1" class="heading">
	<h1>Chemistry Modules<hr style="display:block;background-color:#2B3856;padding:3px;border:none;"></h1>
</div>
<div id="d2" class="description">
	<p1><br>Python program for practical plotting and calculation in chemistry. ChemMod is developed as a userfriendly python package for chemistry students. The package contains a variety of different useful plot functions and formula functions from chemistry e.g. buffer diagrams, gibs energy functions, reaction kinetics order plot linear regression.<br><br></p1> 
</div>
  </foreignObject>
</svgg


Table of contents:

	1.	arrhenius_plot() 
	2.	bjerrum_plot()
	3.	equil()
	4.	gibbs_plot()
	5.	M()
	6.	order_plot()

Built with:
	
	Python - Google Colaboratory
	
	Python packages:
		numpy
		math
		math.plotlib

Requires:

	Python
	numpy as np
	matplotlib as plt


